@@ -13,23 +13,24 @@ class BaseID(GraiBaseModel):
     name: Optional[str]
     namespace: Optional[str]
 
+    def __hash__(self):
+        if self.name is None or self.namespace is None:
+            raise NotImplementedError(
+                f"Computing a hash for {self} requires both name and namespace for compatibility reasons."
+            )
+        return hash(hash(self.name) + hash(self.namespace))
+
 
 class NamedID(BaseID):
     name: str
     namespace: str
     id: Optional[UUID]
 
-    def __hash__(self):
-        return hash(hash(self.name) + hash(self.namespace))
-
 
 class UuidID(BaseID):
     id: UUID
     name: Optional[str]
     namespace: Optional[str]
 
-    def __hash__(self):
-        return hash(self.id)
-
 
 ID = Union[UuidID, NamedID]
